#@ String (value = "surface name" ) str_surf
#@ ResultsTable rt
rt.reset()

/* = CODE DESCRIPTION =
 * This script retrieves Surfaces statistics from Imaris to store them in a Fiji/ImageJ results table.
 *  
 * == INPUTS ==
 * An Imaris file open in Imaris with Surfaces named with user defined value "str_surf".
 *
 * == OUTPUTS ==
 * Fiji results table 
 *
 * = DEPENDENCIES =
 * Imaris
 * EasyXT
 *
 * = INSTALLATION =
 * Imaris installer 
 * Fiji update site PTBIOP
 *
 * = AUTHOR INFORMATION =
 * Code written by Romain Guiet , EPFL - SV - PTECH - BIOP
 * for Charlotte Lorin, Lab LNMC
 * 2023.04.14
 *
 * = COPYRIGHT =
 * (c) All rights reserved. ECOLE POLYTECHNIQUE FEDERALE DE LAUSANNE, Switzerland, BioImaging And Optics Platform (BIOP), 2023
 *
 * Licensed under the BSD-3-Clause License:
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided
 * that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer
 *    in the documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
EasyXT.Utils.resetImarisConnection()

def surf = EasyXT.Surfaces.find(str_surf)
rt = EasyXT.Stats.export( surf );        
rt.show("Surfaces Statistics");  

import ch.epfl.biop.imaris.EasyXT
